==> igniteui-webcomponents-core-1.4.2.tgz: package/esm5/lib/EventProxy.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
/**
 * @hidden
 */
var EventProxy = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(EventProxy, _super);
    function EventProxy() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onMouseWheel = null;
        _this.onMouseWheelHorizontal = null;
        _this.onPinchStarted = null;
        _this.onPinchDelta = null;
        _this.onGestureCompleted = null;
        _this.onZoomStarted = null;
        _this.onZoomDelta = null;
        _this.onZoomCompleted = null;
        _this.onFlingStarted = null;
        _this.onContactStarted = null;
        _this.onManipulationCancelled = null;
        _this.onDragStarted = null;
        _this.onContactMoved = null;
        _this.onDragDelta = null;
        _this.onContactCompleted = null;
        _this.onDragCompleted = null;
        _this.onMouseLeave = null;
        _this.onMouseOver = null;
        _this.onMouseEnter = null;
        _this.onMouseDown = null;
        _this.onMouseUp = null;
        _this.onDoubleTap = null;
        _this.onHold = null;
        _this.onKeyDown = null;
        _this.onKeyUp = null;
        _this.bk = null;
        _this.bh = 0;
        _this.ak = false;
        _this.al = false;
        _this.an = null;
        _this.ap = null;
        _this.aq = null;
        _this.ar = null;
        _this.aa = false;
        _this.ab = false;
        _this.ao = null;
        return _this;
    }
    EventProxy.prototype.ad = function (a, b, c) {
        if (this.ap != null) {
            return this.ap(a, b, c);
        }
        return this.an(a);
    };
    EventProxy.prototype.get_am = function () {
        return false;
    };
    Object.defineProperty(EventProxy.prototype, "am", {
        get: function () {
            return this.get_am();
        },
        enumerable: true,
        configurable: true
    });
    EventProxy.prototype.get_ac = function () {
        return false;
    };
    Object.defineProperty(EventProxy.prototype, "ac", {
        get: function () {
            return this.get_ac();
        },
        enumerable: true,
        configurable: true
    });
    EventProxy.prototype.at = function () {
    };
    EventProxy.prototype.ai = function (a, b) {
        if (this.onMouseWheel != null && !this.ae) {
            return this.onMouseWheel(a, b);
        }
        return false;
    };
    EventProxy.prototype.aj = function (a, b) {
        if (this.onMouseWheelHorizontal != null && !this.ae) {
            return this.onMouseWheelHorizontal(a, b);
        }
        return false;
    };
    EventProxy.prototype.bc = function (a, b) {
        if (this.onPinchStarted != null && !this.ae) {
            this.onPinchStarted(a, b);
        }
    };
    EventProxy.prototype.bf = function (a, b, c, d) {
        if (this.onZoomStarted != null && !this.ae) {
            this.onZoomStarted(a, b, c, d);
        }
    };
    EventProxy.prototype.af = function (a, b, c) {
        if (this.onFlingStarted != null && !this.ae) {
            return this.onFlingStarted(a, b, c);
        }
        return true;
    };
    EventProxy.prototype.bb = function (a, b) {
        if (this.onPinchDelta != null && !this.ae) {
            this.onPinchDelta(a, b);
        }
    };
    EventProxy.prototype.be = function (a, b, c, d) {
        if (this.onZoomDelta != null && !this.ae) {
            this.onZoomDelta(a, b, c, d);
        }
    };
    EventProxy.prototype.bd = function (a, b, c, d) {
        if (this.onZoomCompleted != null && !this.ae) {
            this.onZoomCompleted(a, b, c, d);
        }
    };
    EventProxy.prototype.a3 = function (a, b) {
        if (this.onGestureCompleted != null && !this.ae) {
            this.onGestureCompleted(a, b);
        }
    };
    EventProxy.prototype.a5 = function (a) {
        if (this.onManipulationCancelled != null && !this.ae) {
            this.onManipulationCancelled(a);
        }
    };
    EventProxy.prototype.ay = function (a, b) {
        if (this.onContactStarted != null && !this.ae) {
            this.onContactStarted(a, b);
        }
    };
    EventProxy.prototype.a2 = function (a) {
        if (this.onDragStarted != null && !this.ae) {
            this.onDragStarted(a);
        }
    };
    EventProxy.prototype.ax = function (a, b) {
        if (this.onContactMoved != null && !this.ae) {
            this.onContactMoved(a, b);
        }
    };
    EventProxy.prototype.a1 = function (a) {
        if (this.onDragDelta != null && !this.ae) {
            this.onDragDelta(a);
        }
    };
    EventProxy.prototype.aw = function (a, b, c) {
        if (this.onContactCompleted != null && !this.ae) {
            this.al = c;
            this.onContactCompleted(a, b);
            this.al = false;
        }
    };
    EventProxy.prototype.a0 = function (a) {
        if (this.onDragCompleted != null && !this.ae) {
            this.onDragCompleted(a);
        }
    };
    EventProxy.prototype.a8 = function (a) {
        if (this.onMouseLeave != null && !this.ae) {
            this.onMouseLeave(a);
        }
    };
    EventProxy.prototype.a9 = function (a, b, c) {
        if (this.onMouseOver != null && !this.ae) {
            this.onMouseOver(a, b, c);
        }
    };
    EventProxy.prototype.a7 = function (a) {
        if (this.onMouseEnter != null && !this.ae) {
            this.onMouseEnter(a);
        }
    };
    EventProxy.prototype.a6 = function (a) {
        if (this.onMouseDown != null && !this.ae) {
            this.onMouseDown(a);
        }
    };
    EventProxy.prototype.ba = function (a) {
        if (this.onMouseUp != null && !this.ae) {
            this.onMouseUp(a);
        }
    };
    EventProxy.prototype.ag = function (a) {
        if (this.onKeyDown != null && !this.ae) {
            return this.onKeyDown(a);
        }
        return false;
    };
    EventProxy.prototype.ah = function (a) {
        if (this.onKeyUp != null && !this.ae) {
            return this.onKeyUp(a);
        }
        return false;
    };
    EventProxy.prototype.az = function (a) {
        if (this.onDoubleTap != null && !this.ae) {
            this.onDoubleTap(a);
        }
    };
    EventProxy.prototype.a4 = function (a) {
        if (this.onHold != null && !this.ae) {
            this.onHold(a);
        }
    };
    Object.defineProperty(EventProxy.prototype, "ae", {
        get: function () {
            return this.aa;
        },
        set: function (a) {
            this.aa = a;
            this.av();
        },
        enumerable: true,
        configurable: true
    });
    EventProxy.prototype.av = function () {
    };
    EventProxy.$t = markType(EventProxy, 'EventProxy');
    return EventProxy;
}(Base));
export { EventProxy };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/EventProxy.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
/**
 * @hidden
 */
var EventProxy = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(EventProxy, _super);
    function EventProxy() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onMouseWheel = null;
        _this.onMouseWheelHorizontal = null;
        _this.onPinchStarted = null;
        _this.onPinchDelta = null;
        _this.onGestureCompleted = null;
        _this.onZoomStarted = null;
        _this.onZoomDelta = null;
        _this.onZoomCompleted = null;
        _this.onFlingStarted = null;
        _this.onContactStarted = null;
        _this.onManipulationCancelled = null;
        _this.onDragStarted = null;
        _this.onContactMoved = null;
        _this.onDragDelta = null;
        _this.onContactCompleted = null;
        _this.onDragCompleted = null;
        _this.onMouseLeave = null;
        _this.onMouseOver = null;
        _this.onMouseEnter = null;
        _this.onMouseDown = null;
        _this.onMouseUp = null;
        _this.onDoubleTap = null;
        _this.onHold = null;
        _this.onKeyDown = null;
        _this.onKeyUp = null;
        _this.bl = null;
        _this.bi = 0;
        _this.al = false;
        _this.am = false;
        _this.ao = null;
        _this.aq = null;
        _this.ar = null;
        _this.as = null;
        _this.aa = false;
        _this.ab = false;
        _this.af = false;
        _this.ap = null;
        return _this;
    }
    EventProxy.prototype.ad = function (a, b, c) {
        if (this.aq != null) {
            return this.aq(a, b, c);
        }
        return this.ao(a);
    };
    EventProxy.prototype.get_an = function () {
        return false;
    };
    Object.defineProperty(EventProxy.prototype, "an", {
        get: function () {
            return this.get_an();
        },
        enumerable: true,
        configurable: true
    });
    EventProxy.prototype.get_ac = function () {
        return false;
    };
    Object.defineProperty(EventProxy.prototype, "ac", {
        get: function () {
            return this.get_ac();
        },
        enumerable: true,
        configurable: true
    });
    EventProxy.prototype.au = function () {
    };
    EventProxy.prototype.aj = function (a, b) {
        if (this.onMouseWheel != null && !this.ae) {
            return this.onMouseWheel(a, b);
        }
        return false;
    };
    EventProxy.prototype.ak = function (a, b) {
        if (this.onMouseWheelHorizontal != null && !this.ae) {
            return this.onMouseWheelHorizontal(a, b);
        }
        return false;
    };
    EventProxy.prototype.bd = function (a, b) {
        if (this.onPinchStarted != null && !this.ae) {
            this.onPinchStarted(a, b);
        }
    };
    EventProxy.prototype.bg = function (a, b, c, d) {
        if (this.onZoomStarted != null && !this.ae) {
            this.onZoomStarted(a, b, c, d);
        }
    };
    EventProxy.prototype.ag = function (a, b, c) {
        if (this.onFlingStarted != null && !this.ae) {
            return this.onFlingStarted(a, b, c);
        }
        return true;
    };
    EventProxy.prototype.bc = function (a, b) {
        if (this.onPinchDelta != null && !this.ae) {
            this.onPinchDelta(a, b);
        }
    };
    EventProxy.prototype.bf = function (a, b, c, d) {
        if (this.onZoomDelta != null && !this.ae) {
            this.onZoomDelta(a, b, c, d);
        }
    };
    EventProxy.prototype.be = function (a, b, c, d) {
        if (this.onZoomCompleted != null && !this.ae) {
            this.onZoomCompleted(a, b, c, d);
        }
    };
    EventProxy.prototype.a4 = function (a, b) {
        if (this.onGestureCompleted != null && !this.ae) {
            this.onGestureCompleted(a, b);
        }
    };
    EventProxy.prototype.a6 = function (a) {
        if (this.onManipulationCancelled != null && !this.ae) {
            this.onManipulationCancelled(a);
        }
    };
    EventProxy.prototype.az = function (a, b) {
        if (this.onContactStarted != null && !this.ae) {
            this.onContactStarted(a, b);
        }
    };
    EventProxy.prototype.a3 = function (a) {
        if (this.onDragStarted != null && !this.ae) {
            this.onDragStarted(a);
        }
    };
    EventProxy.prototype.ay = function (a, b) {
        if (this.onContactMoved != null && !this.ae) {
            this.onContactMoved(a, b);
        }
    };
    EventProxy.prototype.a2 = function (a) {
        if (this.onDragDelta != null && !this.ae) {
            this.onDragDelta(a);
        }
    };
    EventProxy.prototype.ax = function (a, b, c) {
        if (this.onContactCompleted != null && !this.ae) {
            this.am = c;
            this.onContactCompleted(a, b);
            this.am = false;
        }
    };
    EventProxy.prototype.a1 = function (a) {
        if (this.onDragCompleted != null && !this.ae) {
            this.onDragCompleted(a);
        }
    };
    EventProxy.prototype.a9 = function (a) {
        if (this.onMouseLeave != null && !this.ae) {
            this.onMouseLeave(a);
        }
    };
    EventProxy.prototype.ba = function (a, b, c) {
        if (this.onMouseOver != null && !this.ae) {
            this.onMouseOver(a, b, c);
        }
    };
    EventProxy.prototype.a8 = function (a) {
        if (this.onMouseEnter != null && !this.ae) {
            this.onMouseEnter(a);
        }
    };
    EventProxy.prototype.a7 = function (a) {
        if (this.onMouseDown != null && !this.ae) {
            this.onMouseDown(a);
        }
    };
    EventProxy.prototype.bb = function (a) {
        if (this.onMouseUp != null && !this.ae) {
            this.onMouseUp(a);
        }
    };
    EventProxy.prototype.ah = function (a) {
        if (this.onKeyDown != null && !this.ae) {
            return this.onKeyDown(a);
        }
        return false;
    };
    EventProxy.prototype.ai = function (a) {
        if (this.onKeyUp != null && !this.ae) {
            return this.onKeyUp(a);
        }
        return false;
    };
    EventProxy.prototype.a0 = function (a) {
        if (this.onDoubleTap != null && !this.ae) {
            this.onDoubleTap(a);
        }
    };
    EventProxy.prototype.a5 = function (a) {
        if (this.onHold != null && !this.ae) {
            this.onHold(a);
        }
    };
    Object.defineProperty(EventProxy.prototype, "ae", {
        get: function () {
            return this.aa;
        },
        set: function (a) {
            this.aa = a;
            this.aw();
        },
        enumerable: true,
        configurable: true
    });
    EventProxy.prototype.aw = function () {
    };
    EventProxy.$t = markType(EventProxy, 'EventProxy');
    return EventProxy;
}(Base));
export { EventProxy };
